@@ -7,6 +7,7 @@ import (
 	"io"
 	"io/fs"
 	"os"
+	"os/user"
 	"path/filepath"
 )
 
@@ -17,7 +18,8 @@ type File struct {
 
 type Opt func(*File)
 
-// New returns a new File
+// New returns a new File.
+// The last successful option determines the filename.
 func New(opts ...Opt) *File {
 	f := File{perms: 0o600}
 	for _, fn := range opts {
@@ -29,15 +31,34 @@ func New(opts ...Opt) *File {
 	return &f
 }
 
-// WithDirName determines the filename from a subdirectory in the user's HOME
-// e.g. dir=".app", name="config.json", sets the fullname to "$HOME/.app/config.json"
-func WithDirName(dir, name string) Opt {
+// WithAppDir determines the filename from the XDG or Windows specification.
+// By default, this is based in $HOME/.config on Linux and %APPDATA% on Windows.
+// If the file does not exist, this will set the filename only if "force" is true.
+func WithAppDir(unixDir, winDir, name string, force bool) Opt {
+	var dir string
+	if winDir == "" {
+		dir = unixDir
+	} else {
+		dir = osString(unixDir, winDir)
+	}
 	return func(f *File) {
-		f.fullname = filepath.Join(homedir(), dir, name)
+		fullname := filepath.Join(appDir(), dir, name)
+		if force || exists(fullname) {
+			f.fullname = fullname
+		}
 	}
 }
 
-// WithEnvFile sets the fullname to the environment value if defined
+// WithDirName determines the filename from a subdirectory in the user's HOME.
+//
+// Deprecated: Replace with [WithHomeDir]
+//
+//go:fix inline
+func WithDirName(dir, name string) Opt {
+	return WithHomeDir(dir, name, true)
+}
+
+// WithEnvFile sets the fullname to the environment value if defined.
 func WithEnvFile(envVar string) Opt {
 	return func(f *File) {
 		val := os.Getenv(envVar)
@@ -47,7 +68,7 @@ func WithEnvFile(envVar string) Opt {
 	}
 }
 
-// WithEnvDir sets the fullname to the environment value + filename if the environment variable is defined
+// WithEnvDir sets the fullname to the environment value + filename if the environment variable is defined.
 func WithEnvDir(envVar, name string) Opt {
 	return func(f *File) {
 		val := os.Getenv(envVar)
@@ -57,14 +78,27 @@ func WithEnvDir(envVar, name string) Opt {
 	}
 }
 
-// WithFullname specifies the filename
+// WithFullname specifies the filename.
+// This will always set the filename even if the file does not exist.
 func WithFullname(fullname string) Opt {
 	return func(f *File) {
 		f.fullname = fullname
 	}
 }
 
-// WithPerms specifies the permissions to create a file with (default 0600)
+// WithHomeDir determines the filename from a subdirectory in the user's HOME
+// e.g. dir=".app", name="config.json", sets the fullname to "$HOME/.app/config.json".
+// If the file does not exist, this will set the filename only if "force" is true.
+func WithHomeDir(dir, name string, force bool) Opt {
+	return func(f *File) {
+		filename := filepath.Join(homeDir(), dir, name)
+		if force || exists(filename) {
+			f.fullname = filename
+		}
+	}
+}
+
+// WithPerms specifies the permissions to create a file with (default 0600).
 func WithPerms(perms int) Opt {
 	return func(f *File) {
 		f.perms = perms
@@ -124,12 +158,31 @@ func (f *File) Write(rdr io.Reader) error {
 	}
 
 	// update mode and owner of temp file
+	//#nosec G703 tempfile location is user controlled
 	if err := os.Chmod(tmpFullname, mode); err != nil {
 		return err
 	}
 	if uid > 0 && gid > 0 {
+		//#nosec G703 tempfile location is user controlled
 		_ = os.Chown(tmpFullname, uid, gid)
 	}
 	// move temp file to target filename
+	//#nosec G703 tempfile location is user controlled
 	return os.Rename(tmpFullname, f.fullname)
 }
+
+func exists(name string) bool {
+	_, err := os.Stat(name)
+	return err == nil
+}
+
+func homeDir() string {
+	home := os.Getenv(homeEnv)
+	if home == "" {
+		u, err := user.Current()
+		if err == nil {
+			home = u.HomeDir
+		}
+	}
+	return home
+}
