@@ -251,8 +251,7 @@ func WithEnv(name, value string) Opts {
 		platforms := []platform.Platform{}
 		if name[0] == '[' && strings.Index(name, "]") > 0 {
 			end := strings.Index(name, "]")
-			list := strings.Split(name[1:end], ",")
-			for _, entry := range list {
+			for entry := range strings.SplitSeq(name[1:end], ",") {
 				entry = strings.TrimSpace(entry)
 				if entry == "*" {
 					continue
@@ -372,8 +371,7 @@ func WithLabel(name, value string) Opts {
 		platforms := []platform.Platform{}
 		if name[0] == '[' && strings.Index(name, "]") > 0 {
 			end := strings.Index(name, "]")
-			list := strings.Split(name[1:end], ",")
-			for _, entry := range list {
+			for entry := range strings.SplitSeq(name[1:end], ",") {
 				entry = strings.TrimSpace(entry)
 				if entry == "*" {
 					continue
