@@ -296,7 +296,7 @@ func OCIIndexFromAny(orig any) (v1.Index, error) {
 func OCIIndexToAny(ociI v1.Index, origP any) error {
 	// reflect is used to handle both *interface and *Manifest
 	rv := reflect.ValueOf(origP)
-	for rv.IsValid() && rv.Type().Kind() == reflect.Ptr {
+	for rv.IsValid() && rv.Type().Kind() == reflect.Pointer {
 		rv = rv.Elem()
 	}
 	if !rv.IsValid() {
@@ -344,7 +344,7 @@ func OCIManifestFromAny(orig any) (v1.Manifest, error) {
 func OCIManifestToAny(ociM v1.Manifest, origP any) error {
 	// reflect is used to handle both *interface and *Manifest
 	rv := reflect.ValueOf(origP)
-	for rv.IsValid() && rv.Type().Kind() == reflect.Ptr {
+	for rv.IsValid() && rv.Type().Kind() == reflect.Pointer {
 		rv = rv.Elem()
 	}
 	if !rv.IsValid() {
